@@ -62,6 +62,18 @@ gconf_search_not_found_dialog (GConfEditorWindow *window)
 	
 }
 
+static void
+gconf_search_entry_changed (GtkEntry *entry, GConfSearchDialog *dialog)
+{
+        gboolean find_sensitive;
+        const gchar *text;
+
+        text = gtk_entry_get_text (GTK_ENTRY (entry));
+        find_sensitive = text != NULL && text[0] != '\0';
+
+        gtk_widget_set_sensitive (dialog->search_button, find_sensitive);
+}
+
 static void
 gconf_search_dialog_search (GtkWidget *button, GConfSearchDialog *dialog)
 {
@@ -94,6 +106,10 @@ gconf_search_dialog_search (GtkWidget *button, GConfSearchDialog *dialog)
 	g_free (pattern);
 
 	if (dialog != NULL) {
+		g_signal_handlers_disconnect_by_func (dialog->entry,
+						      G_CALLBACK (gconf_search_entry_changed), dialog);
+		g_signal_handlers_disconnect_by_func (dialog->search_button,
+						      G_CALLBACK (gconf_search_dialog_search), dialog);
 		gdk_window_set_cursor (GTK_WIDGET (dialog)->window, NULL);
 		gdk_display_flush (gtk_widget_get_display (GTK_WIDGET (dialog)));
 
@@ -105,19 +121,6 @@ gconf_search_dialog_search (GtkWidget *button, GConfSearchDialog *dialog)
 	}
 }
 
-
-static void
-gconf_search_entry_changed (GtkEntry *entry, GConfSearchDialog *dialog)
-{
-	gboolean find_sensitive;
-	const gchar *text;
-
-	text = gtk_entry_get_text (GTK_ENTRY (entry));
-	find_sensitive = text != NULL && text[0] != '\0';
-	
-	gtk_widget_set_sensitive (dialog->search_button, find_sensitive);
-}
-
 static void
 gconf_search_dialog_init (GConfSearchDialog *dialog)
 {
